==> chromium_120.0.6099.224.orig.tar.xz: chromium-120.0.6099.224/base/fuchsia/scoped_natural_service_publisher_unittest.cc <==
// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "base/fuchsia/scoped_service_publisher.h"

#include <fidl/base.testfidl/cpp/fidl.h>
#include <fuchsia/io/cpp/fidl.h>
#include <lib/async/default.h>
#include <lib/fidl/cpp/interface_handle.h>
#include <lib/fidl/cpp/interface_ptr.h>
#include <lib/sys/cpp/component_context.h>
#include <lib/sys/cpp/service_directory.h>
#include <lib/vfs/cpp/pseudo_dir.h>

#include "base/fuchsia/process_context.h"
#include "base/fuchsia/test_component_context_for_process.h"
#include "base/fuchsia/test_interface_natural_impl.h"
#include "base/test/task_environment.h"
#include "testing/gtest/include/gtest/gtest.h"

namespace base {

class ScopedNaturalServicePublisherTest : public testing::Test {
 protected:
  ScopedNaturalServicePublisherTest() = default;
  ~ScopedNaturalServicePublisherTest() override = default;

  const base::test::SingleThreadTaskEnvironment task_environment_{
      base::test::SingleThreadTaskEnvironment::MainThreadType::IO};

  TestComponentContextForProcess test_context_;
  TestInterfaceNaturalImpl test_service_;
};

TEST_F(ScopedNaturalServicePublisherTest, OutgoingDirectory) {
  fidl::Client<base_testfidl::TestInterface> client_a;

  {
    ScopedNaturalServicePublisher<base_testfidl::TestInterface> publisher(
        base::ComponentContextForProcess()->outgoing().get(),
        test_service_.bindings().CreateHandler(&test_service_,
                                               async_get_default_dispatcher(),
                                               [](fidl::UnbindInfo info) {}));
    client_a = base::CreateTestInterfaceClient(
        test_context_.published_services_natural());
    EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);
  }

  // Existing channels remain valid after the publisher goes out of scope.
  EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);

  // New connections attempts will be dropped.
  auto client_b = base::CreateTestInterfaceClient(
      test_context_.published_services_natural());
  EXPECT_EQ(VerifyTestInterface(client_b), ZX_ERR_PEER_CLOSED);
}

TEST_F(ScopedNaturalServicePublisherTest, PseudoDir) {
  vfs::PseudoDir directory;
  auto pseudodir_endpoints = fidl::CreateEndpoints<fuchsia_io::Directory>();
  ASSERT_TRUE(pseudodir_endpoints.is_ok())
      << pseudodir_endpoints.status_string();
  directory.Serve(fuchsia::io::OpenFlags::RIGHT_READABLE |
                      fuchsia::io::OpenFlags::RIGHT_WRITABLE,
                  pseudodir_endpoints->server.TakeChannel());

  fidl::Client<base_testfidl::TestInterface> client_a;

  {
    ScopedNaturalServicePublisher<base_testfidl::TestInterface> publisher(
        &directory, test_service_.bindings().CreateHandler(
                        &test_service_, async_get_default_dispatcher(),
                        [](fidl::UnbindInfo info) {}));
    client_a =
        base::CreateTestInterfaceClient(pseudodir_endpoints->client.borrow());
    EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);
  }

  // Existing channels remain valid after the publisher goes out of scope.
  EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);

  // New connection attempts will be dropped.
  auto client_b =
      base::CreateTestInterfaceClient(pseudodir_endpoints->client.borrow());
  EXPECT_EQ(VerifyTestInterface(client_b), ZX_ERR_PEER_CLOSED);
}

}  // namespace base

==> chromium_128.0.6613.84.orig.tar.xz: chromium-128.0.6613.84/base/fuchsia/scoped_natural_service_publisher_unittest.cc <==
// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "base/fuchsia/scoped_service_publisher.h"

#include <fidl/base.testfidl/cpp/fidl.h>
#include <fuchsia/io/cpp/fidl.h>
#include <lib/async/default.h>
#include <lib/fidl/cpp/interface_handle.h>
#include <lib/fidl/cpp/interface_ptr.h>
#include <lib/sys/cpp/component_context.h>
#include <lib/sys/cpp/service_directory.h>
#include <lib/vfs/cpp/pseudo_dir.h>

#include "base/fuchsia/process_context.h"
#include "base/fuchsia/test_component_context_for_process.h"
#include "base/fuchsia/test_interface_natural_impl.h"
#include "base/test/task_environment.h"
#include "testing/gmock/include/gmock/gmock.h"
#include "testing/gtest/include/gtest/gtest.h"

namespace base {

class ScopedNaturalServicePublisherTest : public testing::Test {
 protected:
  ScopedNaturalServicePublisherTest() = default;
  ~ScopedNaturalServicePublisherTest() override = default;

  const base::test::SingleThreadTaskEnvironment task_environment_{
      base::test::SingleThreadTaskEnvironment::MainThreadType::IO};

  TestComponentContextForProcess test_context_;
  TestInterfaceNaturalImpl test_service_;
};

TEST_F(ScopedNaturalServicePublisherTest, OutgoingDirectory) {
  fidl::Client<base_testfidl::TestInterface> client_a;

  {
    ScopedNaturalServicePublisher<base_testfidl::TestInterface> publisher(
        base::ComponentContextForProcess()->outgoing().get(),
        test_service_.bindings().CreateHandler(&test_service_,
                                               async_get_default_dispatcher(),
                                               [](fidl::UnbindInfo info) {}));
    client_a = base::CreateTestInterfaceClient(
        test_context_.published_services_natural());
    EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);
  }

  // Existing channels remain valid after the publisher goes out of scope.
  EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);

  // New connection attempts should fail immediately.
  auto client_b = base::CreateTestInterfaceClient(
      test_context_.published_services_natural());
  // TODO(https://fxbug.dev/293955890): Only check for ZX_ERR_NOT_FOUND once
  // https://fuchsia-review.git.corp.google.com/c/fuchsia/+/1058032 lands.
  EXPECT_THAT(VerifyTestInterface(client_b),
              testing::AnyOf(testing::Eq(ZX_ERR_PEER_CLOSED),
                             testing::Eq(ZX_ERR_NOT_FOUND)));
}

TEST_F(ScopedNaturalServicePublisherTest, PseudoDir) {
  vfs::PseudoDir directory;
  auto pseudodir_endpoints = fidl::CreateEndpoints<fuchsia_io::Directory>();
  ASSERT_TRUE(pseudodir_endpoints.is_ok())
      << pseudodir_endpoints.status_string();
  directory.Serve(fuchsia::io::OpenFlags::RIGHT_READABLE |
                      fuchsia::io::OpenFlags::RIGHT_WRITABLE,
                  pseudodir_endpoints->server.TakeChannel());

  fidl::Client<base_testfidl::TestInterface> client_a;

  {
    ScopedNaturalServicePublisher<base_testfidl::TestInterface> publisher(
        &directory, test_service_.bindings().CreateHandler(
                        &test_service_, async_get_default_dispatcher(),
                        [](fidl::UnbindInfo info) {}));
    client_a =
        base::CreateTestInterfaceClient(pseudodir_endpoints->client.borrow());
    EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);
  }

  // Existing channels remain valid after the publisher goes out of scope.
  EXPECT_EQ(VerifyTestInterface(client_a), ZX_OK);

  // New connection attempts should fail immediately.
  auto client_b =
      base::CreateTestInterfaceClient(pseudodir_endpoints->client.borrow());
  // TODO(https://fxbug.dev/293955890): Only check for ZX_ERR_NOT_FOUND once
  // https://fuchsia-review.git.corp.google.com/c/fuchsia/+/1058032 lands.
  EXPECT_THAT(VerifyTestInterface(client_b),
              testing::AnyOf(testing::Eq(ZX_ERR_PEER_CLOSED),
                             testing::Eq(ZX_ERR_NOT_FOUND)));
}

}  // namespace base
